@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+
 class MobileCommand(object):
     CONTEXTS = 'getContexts',
     GET_CURRENT_CONTEXT = 'getCurrentContext',
@@ -36,3 +37,5 @@ class MobileCommand(object):
     END_TEST_COVERAGE = 'endTestCoverage'
     LOCK = 'lock'
     SHAKE = 'shake'
+    RESET = 'reset'
+    HIDE_KEYBOARD = 'hideKeyboard'
